---
hide:
    - navigation
---

# CTF Architect

A CTF challenge management tool

!!! warning
    This tool is still a work in progress, bugs are to be expected. If you find any, please open an [issue](https://github.com/Jus-Codin/CTF-Architect/issues)

---

<p align="center">
    <a href="https://pypi.org/project/ctf-architect/" target="_blank">
        <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/ctf-architect">
    </a>
    <a href="https://pypi.org/project/ctf-architect/" target="_blank">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/ctf-architect">
    </a>
</p>

---

Github: <a href="https://github.com/Jus-Codin/CTF-Architect" target="_blank">https://github.com/Jus-Codin/CTF-Architect</a>

Documentation: <a href="https://jus-codin.github.io/CTF-Architect/" target="_blank">https://jus-codin.github.io/CTF-Architect/</a>

---

## Getting Started
- [Introduction](./introduction.md)
- [Installation](./installation.md)

## Usage
- [Pacakging challenges](./guides/packaging-challenges.md)
- [Set up a challenge repository](./guides/repository-setup.md)

## Specifications
- [Challenge](./spec/challenge.md)
- [Repository](./spec/repository.md)